package com.datacloudsec.scan.service.impl;

import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.cache.WebProxyConfig;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.WebProxyMapper;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.entity.WebConfig;
import com.datacloudsec.scan.service.IWebProxy;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.JsonUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.datacloudsec.utils.PoiExcelUtils;
import java.io.File;
import java.io.FileOutputStream;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpSession;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.io.FileUtils;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang.ArrayUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.poi.hssf.usermodel.DVConstraint;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFCellStyle;
import org.apache.poi.hssf.usermodel.HSSFDataValidation;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.util.CellRangeAddressList;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/WebProxyService.class */
public class WebProxyService implements IWebProxy {
    private WebProxyMapper webProxy = (WebProxyMapper) InstanceUtil.newDaoInstance(WebProxyMapper.class);

    public int searchCount(HttpSession session, String name) throws Exception {
        return this.webProxy.searchCount(name, DataRule.getRuleWhere(session, "t_web_proxy"));
    }

    public List<Map<String, Object>> search(HttpSession session, String name, Integer offset, Integer limit) throws Exception {
        List<Map<String, Object>> webProxyList = this.webProxy.search(name, offset, limit, DataRule.getRuleWhere(session, "t_web_proxy"));
        Map<String, WebConfig> webConfig = WebProxyConfig.getInstance().getWebConfig();
        for (Map<String, Object> proxy : webProxyList) {
            String proxyConfig = ObjectUtil.getString(proxy.get("config"), "");
            if (!"".equals(proxyConfig)) {
                Map<String, Object> config = (Map) JsonUtil.MAPPER_ESCAPE_HTML.readValue(proxyConfig, HashMap.class);
                proxy.put("proxyType", ObjectUtil.getString(config.get("proxyType"), ""));
                proxy.put("proxyHost", ObjectUtil.getString(config.get("proxyHost"), ""));
                proxy.put("proxyPort", ObjectUtil.getString(config.get("proxyPort"), ""));
                String[] values = webConfig.get("proxyAuth").getValue().split("\\|");
                String[] valueDesc = webConfig.get("proxyAuth").getValueDesc().split("\\|");
                proxy.put("proxyAuth", valueDesc[ArrayUtils.indexOf(values, ObjectUtil.getString(config.get("proxyAuth"), ""))]);
                proxy.put("proxyUsername", ObjectUtil.getString(config.get("proxyUsername"), ""));
                proxy.put("proxyPwd", ObjectUtil.getString(config.get("proxyPwd"), ""));
                proxy.put("proxyDomain", ObjectUtil.getString(config.get("proxyDomain"), ""));
            }
        }
        return webProxyList;
    }

    public void delete(HttpSession session, Integer id, Integer version) throws Exception {
        Integer count = this.webProxy.getCountWebByWid(id);
        if (count != null && count.intValue() > 0) {
            throw new UEException("此模板已被网站引用，请在资产管理中移除引用关系！");
        }
        Integer vcount = Integer.valueOf(this.webProxy.delete(id, version, DataRule.getRuleWhere(session, "t_web_proxy")));
        if (vcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
    }

    public void insert(HttpSession session, String name, String config) throws Exception {
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.webProxy.getCountByName(name, (Integer) null, uid);
        if (count != null && count.intValue() > 0) {
            throw new UEException("模板名称已存在！");
        }
        this.webProxy.insert(name, config, uid);
    }

    public void update(HttpSession session, Integer id, String name, String config, Integer version) throws Exception {
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.webProxy.getCountByName(name, id, uid);
        if (count != null && count.intValue() > 0) {
            throw new UEException("模板名称已存在");
        }
        Integer vcount = Integer.valueOf(this.webProxy.update(id, name, config, version, DataRule.getRuleWhere(session, "t_web_proxy"), uid));
        if (vcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
    }

    public Map<String, Object> getTemplateById(Integer id) throws Exception {
        return this.webProxy.getTemplateById(id);
    }

    public File proxyExp(HttpSession session, String name) throws Exception {
        String[] headers = {"模板名称@name@8000", "代理类型@proxyType@8000", "IP地址@proxyHost@4000", "端口号@proxyPort@4000", "代理认证类型@proxyAuth@8000", "用户名@proxyUsername@4000", "密码@proxyPwd@4000", "域@proxyDomain@8000"};
        PoiExcelUtils poiExcelUtil = new PoiExcelUtils();
        HSSFWorkbook hssfWorkbook = poiExcelUtil.getHSSFWorkbook();
        HSSFSheet hssfSheet = poiExcelUtil.getHSSFSheet(hssfWorkbook, "代理服务器模板");
        poiExcelUtil.writeHeader(hssfWorkbook, hssfSheet, headers, "代理服务器模板");
        writeContentCustom(poiExcelUtil, hssfWorkbook, hssfSheet, headers, search(session, name, null, null), 2);
        File f = new File(Constant.WORK_DIR, ObjectUtil.getString(String.valueOf(System.currentTimeMillis()) + ".xls", ""));
        FileOutputStream out = null;
        try {
            try {
                out = FileUtils.openOutputStream(f);
                hssfWorkbook.write(out);
                IOUtils.closeQuietly(out);
                return f;
            } catch (Exception e) {
                throw e;
            }
        } catch (Throwable th) {
            IOUtils.closeQuietly(out);
            throw th;
        }
    }

    private void writeContentCustom(PoiExcelUtils poiExcelUtils, HSSFWorkbook hssfWorkbook, HSSFSheet hssfSheet, String[] headers, List<?> dataList, int startIndex) throws Exception {
        Object cellValue = null;
        int rownum = startIndex;
        HSSFCellStyle cellStyle = poiExcelUtils.createContentCellStyle(hssfWorkbook);
        List<WebConfig> webType = WebProxyConfig.getInstance().getProxy();
        String[] proxyType = null;
        String[] proxyAuth = null;
        Map<String, Map<String, Object>> seleMap = new HashMap<>();
        Map<String, Object> typeMap = new HashMap<>();
        Map<String, Object> authtypeMap = new HashMap<>();
        int len = webType.size();
        for (int i = 0; i < len; i++) {
            WebConfig webconfig = webType.get(i);
            if ("select".equals(webconfig.getType())) {
                if ("proxyType".equals(webconfig.getName())) {
                    proxyType = webconfig.getValueDesc().split("\\|");
                    String[] valueArr = webconfig.getValue().split("\\|");
                    for (int j = 0; j < proxyType.length; j++) {
                        typeMap.put(valueArr[j], proxyType[j]);
                    }
                } else if ("proxyAuth".equals(webconfig.getName())) {
                    proxyAuth = webconfig.getValueDesc().split("\\|");
                    String[] valueArr2 = webconfig.getValue().split("\\|");
                    for (int j2 = 0; j2 < proxyAuth.length; j2++) {
                        authtypeMap.put(valueArr2[j2], proxyAuth[j2]);
                    }
                }
            }
        }
        seleMap.put("proxyType", typeMap);
        seleMap.put("proxyAuth", authtypeMap);
        Map<String, String[]> selectList = new HashMap<>();
        selectList.put("proxyType", proxyType);
        selectList.put("proxyAuth", proxyAuth);
        if (CollectionUtils.isEmpty(dataList)) {
            int len2 = headers.length;
            for (int i2 = 0; i2 < len2; i2++) {
                String key = ObjectUtil.getString(headers[i2].split("@")[1].trim(), "");
                if (key.equals("proxyType") || key.equals("proxyAuth")) {
                    CellRangeAddressList cellist = new CellRangeAddressList(2, 65535, i2, i2);
                    DVConstraint constraint = DVConstraint.createExplicitListConstraint(selectList.get(key));
                    HSSFDataValidation validation = new HSSFDataValidation(cellist, constraint);
                    hssfSheet.addValidationData(validation);
                }
            }
            return;
        }
        int size = dataList.size();
        for (int j3 = 0; j3 < size; j3++) {
            HSSFRow row = hssfSheet.createRow(rownum);
            Map<String, Object> map = (Map) dataList.get(j3);
            int len3 = headers.length;
            for (int i3 = 0; i3 < len3; i3++) {
                HSSFCell cell = row.createCell(i3);
                String key2 = ObjectUtil.getString(headers[i3].split("@")[1].trim(), "");
                if (map != null) {
                    Map<String, Object> smap = seleMap.get(key2);
                    if (key2.equals("proxyType") || key2.equals("proxyAuth")) {
                        cellValue = smap.get(map.get(key2));
                        CellRangeAddressList cellist2 = new CellRangeAddressList(j3 + 2, 65535, i3, i3);
                        DVConstraint constraint2 = DVConstraint.createExplicitListConstraint(selectList.get(key2));
                        HSSFDataValidation validation2 = new HSSFDataValidation(cellist2, constraint2);
                        hssfSheet.addValidationData(validation2);
                    } else {
                        cellValue = map.get(key2);
                    }
                }
                poiExcelUtils.cellValueHandler(cell, cellValue);
                cell.setCellStyle(cellStyle);
            }
            rownum++;
        }
    }

    public Map<String, Object> proxyImp(HttpSession session, File f) throws Exception {
        List<String[]> strlist = PoiExcelUtils.readExcel(f.getPath(), 0, 8);
        List<WebConfig> webType = WebProxyConfig.getInstance().getProxy();
        Map<String, Object> proxyType = new HashMap<>();
        Map<String, Object> proxyAuth = new HashMap<>();
        int len = webType.size();
        for (int i = 0; i < len; i++) {
            WebConfig webconfig = webType.get(i);
            if ("select".equals(webconfig.getType())) {
                if ("proxyType".equals(webconfig.getName())) {
                    String[] proxyValueArr = webconfig.getValue().split("\\|");
                    String[] proxyDescArr = webconfig.getValueDesc().split("\\|");
                    int jlen = proxyValueArr.length;
                    for (int j = 0; j < jlen; j++) {
                        proxyType.put(proxyDescArr[j], proxyValueArr[j]);
                    }
                } else if ("proxyAuth".equals(webconfig.getName())) {
                    String[] proxyAuthValueArr = webconfig.getValue().split("\\|");
                    String[] proxyAuthDescArr = webconfig.getValueDesc().split("\\|");
                    int jlen2 = proxyAuthValueArr.length;
                    for (int j2 = 0; j2 < jlen2; j2++) {
                        proxyAuth.put(proxyAuthDescArr[j2], proxyAuthValueArr[j2]);
                    }
                }
            }
        }
        StringBuilder sb = new StringBuilder();
        Map<String, Object> result = new HashMap<>();
        int successCount = 0;
        int len2 = strlist.size();
        for (int i2 = 2; i2 < len2; i2++) {
            String[] strArr = strlist.get(i2);
            if (strArr != null) {
                if (StringUtils.isBlank(strArr[0])) {
                    sb.append("第" + (i2 + 1) + "行，");
                } else {
                    Integer count = this.webProxy.getCountByName(strArr[0], (Integer) null, ((User) session.getAttribute("userInfo")).getId());
                    if (count != null && count.intValue() > 0) {
                        sb.append("第" + (i2 + 1) + "行，");
                    } else if (StringUtils.isBlank(strArr[1]) || proxyType.get(strArr[1]) == null) {
                        sb.append("第" + (i2 + 1) + "行，");
                    } else if (StringUtils.isBlank(strArr[2])) {
                        sb.append("第" + (i2 + 1) + "行，");
                    } else if (StringUtils.isBlank(strArr[3]) || !strArr[3].matches("^([0-9]|[1-9]\\d|[1-9]\\d{2}|[1-9]\\d{3}|[1-5]\\d{4}|6[0-4]\\d{3}|65[0-4]\\d{2}|655[0-2]\\d|6553[0-5])$")) {
                        sb.append("第" + (i2 + 1) + "行，");
                    } else if (StringUtils.isBlank(strArr[4]) || proxyAuth.get(strArr[4]) == null) {
                        sb.append("第" + (i2 + 1) + "行，");
                    } else if (StringUtils.isBlank(strArr[5])) {
                        sb.append("第" + (i2 + 1) + "行，");
                    } else if (StringUtils.isBlank(strArr[6])) {
                        sb.append("第" + (i2 + 1) + "行，");
                    } else {
                        Map<String, Object> config = new HashMap<>();
                        config.put("proxyType", ObjectUtil.getString(proxyType.get(strArr[1]), ""));
                        config.put("proxyHost", strArr[2]);
                        config.put("proxyPort", Integer.valueOf(ObjectUtil.getInt(strArr[3], 0)));
                        config.put("proxyAuth", ObjectUtil.getString(proxyAuth.get(strArr[4]), ""));
                        config.put("proxyUsername", strArr[5]);
                        config.put("proxyPwd", strArr[6]);
                        config.put("proxyDomain", strArr[7]);
                        insert(session, strArr[0], JsonUtil.MAPPER_ESCAPE_HTML.writeValueAsString(config));
                        successCount++;
                    }
                }
            }
        }
        result.put("successCount", Integer.valueOf(successCount));
        result.put("fail", sb);
        return result;
    }

    public List<Map<String, Object>> getWebProxy(HttpSession session) throws Exception {
        return this.webProxy.getWebProxy(DataRule.getRuleWhere(session, "t_web_proxy"));
    }
}
